Interfaces
----------

Same thing as object-oriented programming interfaces.

XXX how to define a cw interface

Declaration of interfaces implemented by a class
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

XXX __implements__


Interfaces defined in the library
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

automodule:: cubicweb.interface   :members:


